# /etc/cron.d/dsc-statistics-presenter: crontab entries for the dsc-presenter package

SHELL=/bin/sh
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin

2,7,12,17,22,27,32,37,42,47,52,57 *    * * *   Debian-dsc-statistics test -x /usr/share/dsc-statistics-presenter/copy-local-and-process-data && /usr/share/dsc-statistics-presenter/copy-local-and-process-data --remove-source-files
